CepResult class

Constructors

CepResult({required String cep, required String logradouro, required String bairro, required String localidade, required String uf})
CepResult.fromJson(Map<String, dynamic> json)
factory

Properties

bairro String
final
cep String
final
hashCode int
The hash code for this object.
no setterinherited
localidade String
final
logradouro String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uf String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited